<?php

namespace Drupal\flex_processor\Plugin;

use Drupal\Core\Field\FieldItemListInterface;

/**
 * Base class for FieldDataProcessor plugin.
 */
abstract class FieldDataProcessor extends DataProcessorBase {

  /**
   * {@inheritdoc}
   */
  public function preProcess(mixed $fields, array $options = []): mixed {

    $processedFields = [];

    // If there are no values to process, return NULL.
    $count = $fields->count();
    if ($count == 0) {
      return NULL;
    }

    // If there is only one value, we can return it directly.
    $isSingleValue = $fields->getFieldDefinition()
      ->getFieldStorageDefinition()
      ->getCardinality() === 1;

    // Process each field item.
    foreach ($fields as $field) {
      if (!$field->isEmpty()) {
        $processedFields[] = $this->process($field, $options);
      }
    }

    // If there are no processed values, return NULL.
    if (empty($processedFields)) {
      return NULL;
    }

    // If there is only one value, return it directly.
    return $isSingleValue ? reset($processedFields) : $processedFields;
  }

}
